# Generated by Django 4.2 on 2022-08-16 11:41

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0136_egfrdropnotification_creatinine_quantifier_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="egfrdropnotification",
            name="egfr_percent_change",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="Copied from RFT result eGFR section.",
                max_digits=10,
                null=True,
                verbose_name="Percent change from baseline",
            ),
        ),
        migrations.AlterField(
            model_name="historicalegfrdropnotification",
            name="egfr_percent_change",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="Copied from RFT result eGFR section.",
                max_digits=10,
                null=True,
                verbose_name="Percent change from baseline",
            ),
        ),
    ]
